// SPDX-FileCopyrightText: 2022 Aleksandr Mezin <mezin.alexander@gmail.com>
//
// SPDX-License-Identifier: GPL-3.0-or-later

'use strict';

const GObject = imports.gi.GObject;
const Gio = imports.gi.Gio;
const Gtk = imports.gi.Gtk;

const Me = imports.misc.extensionUtils.getCurrentExtension();
const { bind_widgets, ui_file_uri } = Me.imports.ddterm.pref.util;

var CompatibilityWidget = GObject.registerClass({
    GTypeName: 'DDTermPrefsCompatibility',
    Template: ui_file_uri('prefs-compatibility.ui'),
    Children: [
        'backspace_binding_combo',
        'delete_binding_combo',
        'ambiguous_width_combo',
    ],
    Properties: {
        'settings': GObject.ParamSpec.object(
            'settings',
            '',
            '',
            GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT_ONLY,
            Gio.Settings
        ),
        'gettext-context': GObject.ParamSpec.jsobject(
            'gettext-context',
            '',
            '',
            GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT_ONLY
        ),
    },
}, class PrefsCompatibility extends Gtk.Grid {
    _init(params) {
        super._init(params);

        bind_widgets(this.settings, {
            'backspace-binding': this.backspace_binding_combo,
            'delete-binding': this.delete_binding_combo,
            'cjk-utf8-ambiguous-width': this.ambiguous_width_combo,
        });

        const reset_action = new Gio.SimpleAction({
            name: 'reset-compatibility-options',
        });

        reset_action.connect('activate', () => {
            this.settings.reset('backspace-binding');
            this.settings.reset('delete-binding');
            this.settings.reset('cjk-utf8-ambiguous-width');
        });

        const aux_actions = new Gio.SimpleActionGroup();
        aux_actions.add_action(reset_action);
        this.insert_action_group('aux', aux_actions);
    }

    get title() {
        return this.gettext_context.gettext('Compatibility');
    }
});

/* exported CompatibilityWidget */
